@@ -4,5 +4,5 @@ function(object, ...)
     ncl <- nclones(object)
     if (is.null(ncl))
         ncl <- 1
-    mcmcapply(object, sd) * sqrt(ncl)
+    mcmcapply(object, sd, ...) * sqrt(ncl)
 }
