@@ -6,6 +6,10 @@ function(cl, data, params, model, inits = NULL, n.chains = 3, ...)
         stop("there is no package called 'rjags'")
     if (!inherits(cl, "cluster"))
         stop("'cl' must be a 'cluster' object")
+    if (is.environment(data)) {
+        warnings("'data' was environment: it was coerced into a list")
+        data <- as.list(data)
+    }
     trace <- getOption("dcoptions")$verbose
     ## eval args
     if (!is.null(list(...)$n.iter))
@@ -13,7 +17,6 @@ function(cl, data, params, model, inits = NULL, n.chains = 3, ...)
             stop("'n.iter = 0' is not supported for parallel computations")
     if (n.chains == 1)
         stop("no need for parallel computing with 1 chain")
-
     ## write model
     if (is.function(model) || inherits(model, "custommodel")) {
         if (is.function(model))
@@ -24,10 +27,17 @@ function(cl, data, params, model, inits = NULL, n.chains = 3, ...)
             on.exit(try(clean.jags.model(model)))
         }
     }
-
     ## generating initial values and RNGs if needed
-    inits <- jags.fit(data, params, model, inits, n.chains,
-        n.adapt=0, n.update=0, n.iter=0)$state(internal=TRUE)
+    if ("lecuyer" %in% list.modules()) {
+        mod <- parListModules(cl)
+        for (i in 1:length(mod)) {
+            if (!("lecuyer" %in% mod[[i]]))
+                stop("'lecuyer' module must be loaded on workers")
+        }
+    }
+    inits <- parallel.inits(inits, n.chains)
+#    inits <- jags.fit(data, params, model, inits, n.chains,
+#        n.adapt=0, n.update=0, n.iter=0)$state(internal=TRUE)
     ## common data to cluster
     cldata <- list(data=data, params=params, model=model, inits=inits)
     ## parallel function to evaluate by snowWrapper
@@ -46,13 +56,11 @@ function(cl, data, params, model, inits = NULL, n.chains = 3, ...)
         "load" else "none"
     dir <- if (inherits(cl, "SOCKcluster"))
         getwd() else NULL
-    ## do the work, dclone loaded only if not yet there  -- went into snowWrapper
-#    lib <- if ("dclone" %in% clusterEvalQ(cl, .packages())[[1]])
-#        NULL else "dclone"
     mcmc <- snowWrapper(cl, 1:n.chains, jagsparallel, cldata, 
         name=NULL, use.env=TRUE,
         lib="dclone", balancing=balancing, size=1, 
-        rng.type=getOption("dcoptions")$RNG, cleanup=TRUE, dir=dir, unload=FALSE, ...)
+        rng.type=getOption("dcoptions")$RNG, cleanup=TRUE, dir=dir, 
+        unload=FALSE, ...)
     ## binding the chains
     res <- as.mcmc.list(lapply(mcmc, as.mcmc))
     ## attaching attribs and return
