@@ -2,6 +2,5 @@ parListFactories <-
 function(cl, type) 
 {
     clusterEvalQ(cl, require(rjags))
-    clusterCall(cl, eval, list.factories(type), env = .GlobalEnv)
+    clusterCall(cl, list.factories, type=type)
 }
-
