@@ -2,6 +2,5 @@ parListModules <-
 function(cl) 
 {
     clusterEvalQ(cl, require(rjags))
-    clusterCall(cl, eval, list.modules(), env = .GlobalEnv)
+    clusterEvalQ(cl, list.modules())
 }
-
