@@ -2,6 +2,6 @@ parSetFactory <-
 function(cl, name, type, state) 
 {
     clusterEvalQ(cl, require(rjags))
-    clusterCall(cl, eval, set.factory(name, type, state), env = .GlobalEnv)
+    clusterCall(cl, set.factory,
+        name=name, type=type, state=state)
 }
-
