@@ -1,3 +1,5 @@
 vcov.mcmc.list <-
 function(object, ...)
-    cov(mcmcapply(object, array))
+{
+    cov(as.matrix(object), ...)
+}
